@@ -153,8 +153,10 @@ pycorba_method_call(PyCORBA_Method *self, PyObject *args, PyObject *kwargs)
 	}
     }
     CORBA_exception_init(&ev);
+    pyorbit_begin_allow_threads;
     ORBit_small_invoke_stub(objref, imethod, ret, argv,
 			    CORBA_OBJECT_NIL, &ev);
+    pyorbit_end_allow_threads;
 
     if (pyorbit_check_ex(&ev))
 	goto cleanup;
